@@ -9,7 +9,7 @@ def legend(*args, **kwargs):
 
     @param args:
     @type args:
-    @param kwargs: Any keyword arugments to matplotlib's plt.legend()
+    @param kwargs: Any keyword arguments to matplotlib's plt.legend()
     Optional 'facecolor' keyword to change the facecolor of the legend
     @type kwargs:
     @return:
@@ -18,10 +18,8 @@ def legend(*args, **kwargs):
     ax, args, kwargs = maybe_get_ax(*args, **kwargs)
     facecolor = kwargs.pop('facecolor', light_grey)
 
-    if 'frameon' not in kwargs:
-        kwargs['frameon'] = True
-    if 'scatterpoints' not in kwargs:
-        kwargs['scatterpoints'] = True
+    kwargs.setdefault('frameon', True)
+    kwargs.setdefault('scatterpoints', True)
 
     legend = ax.legend(**kwargs)
     try:
@@ -29,7 +27,7 @@ def legend(*args, **kwargs):
         rect.set_facecolor(facecolor)
         rect.set_linewidth(0.0)
 
-        # change the label colors in the legend to almost black
+        # Change the label colors in the legend to almost black
         # Change the legend label colors to almost black, too
         texts = legend.texts
         for t in texts:
